'use strict';

exports.__esModule = true;

var _createFetcher = require('./createFetcher.js');

var _createFetcher2 = _interopRequireDefault(_createFetcher);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var createGraphqlGate = function createGraphqlGate(path) {
    var fetcher = (0, _createFetcher2.default)(path);
    return function (action) {
        return action.type === 'batch' ? processBatch(fetcher, action) : processAction(fetcher, action);
    };
};

var processBatch = function processBatch(fetcher, batch) {
    return batch.actions;
};

var processAction = function processAction(fetcher, action) {
    if (action.payload.type === 'mutation') {
        return processMutation(fetcher, action.payload);
    } else if (action.payload.type === 'query') {
        return processQuery(fetcher, action.payload);
    }
};

var processMutation = function processMutation(fetcher, mutation) {
    return fetcher('mutation { ' + mutation.name + '(' + mutation.params + ')' + mutation.query + ' }');
};

var processQuery = function processQuery(fetcher, query) {
    return fetcher('query { ' + query.name + '(' + query.params + ')' + query.query + ' }');
};

exports.default = createGraphqlGate;